@@ -1,15 +1,18 @@
+from __future__ import absolute_import
+
 from django.contrib import admin
 from django.forms.widgets import TextInput
 from django_google_maps import fields as map_fields
 
 from controller.admin.utils import insertattr
 from nodes.models import Node
+from permissions.admin import PermissionTabularInline
 
 from . import widgets as map_widgets
 from .models import Geolocation, NodeGeolocation
 
 
-class GisInline(admin.TabularInline):
+class GisInline(PermissionTabularInline):
     """ Base class for create an inline that provides geolocation info. """
     fields = ['address', 'geolocation']
     model = Geolocation
