@@ -3,14 +3,15 @@ from __future__ import absolute_import
 import json
 import six
 
-from api import serializers, exceptions
-from api.validators import validate_properties
+from api import serializers
 
 from . import settings
 from .models import DirectIface, Island, Node, Server
 
 
 class ServerSerializer(serializers.UriHyperlinkedModelSerializer):
+    properties = serializers.PropertyField()
+    
     class Meta:
         model = Server
 
@@ -43,9 +44,12 @@ class IslandSerializer(serializers.UriHyperlinkedModelSerializer):
         model = Island
 
 
+#239 Remove firmware configuration cruft from data model
+FW_CONFIG_FIELDS = ('local_iface', 'priv_ipv4_prefix', 'sliver_pub_ipv6',
+    'sliver_pub_ipv4', 'sliver_pub_ipv4_range', 'sliver_mac_prefix')
 class NodeCreateSerializer(serializers.UriHyperlinkedModelSerializer):
     id = serializers.Field()
-    properties = serializers.PropertyField(default={})
+    properties = serializers.PropertyField()
     arch = serializers.ChoiceField(choices=settings.NODES_NODE_ARCHS, required=True)
     slivers = serializers.RelHyperlinkedRelatedField(many=True, read_only=True,
         view_name='sliver-detail')
@@ -53,17 +57,10 @@ class NodeCreateSerializer(serializers.UriHyperlinkedModelSerializer):
     cert = serializers.Field()
     boot_sn = serializers.IntegerField(read_only=True)
     
-    # FIXME #239 Remove firmware configuration cruft from data model
-    # talk before with Axel and coordinate with Node firmware
-    local_iface = serializers.CharField(required=False)#True)
-    sliver_pub_ipv6 = serializers.ChoiceField(choices=Node.IPV6_METHODS, required=False)
-    sliver_pub_ipv4 = serializers.ChoiceField(choices=Node.IPV4_METHODS, required=False)
-    sliver_pub_ipv4_range = serializers.CharField(required=False)
-    
     class Meta:
         model = Node
-        exclude = ('set_state',)
-    
+        exclude = ('set_state',) + FW_CONFIG_FIELDS
+
     def get_fields(self, *args, **kwargs):
         """
         Filter groups: the user creating this node must be a
@@ -84,11 +81,9 @@ class NodeCreateSerializer(serializers.UriHyperlinkedModelSerializer):
             fields['group'].queryset = queryset.filter(allow_nodes=True,
                                         roles__user=user.id, roles__is_group_admin=True)
         return fields
-    
-    def validate_properties(self, attrs, source):
-        return validate_properties(self, attrs, source)
 
 class NodeSerializer(NodeCreateSerializer):
     class Meta:
         model = Node
+        exclude = FW_CONFIG_FIELDS
         read_only_fields = ('group',)
