@@ -10,6 +10,7 @@ from django.core.urlresolvers import reverse
 from django.http import HttpResponse, Http404
 from django.shortcuts import get_object_or_404, render_to_response
 from django.utils import timezone
+from django.utils.html import escape
 from django.utils.safestring import mark_safe
 from pygments import highlight
 from pygments.lexers import JsonLexer
@@ -49,7 +50,7 @@ STATES_COLORS.update({
     'registered': SLIVER_STATES_COLORS[Slice.REGISTER],
     'deployed': SLIVER_STATES_COLORS[Slice.DEPLOY],
     'started': SLIVER_STATES_COLORS[Slice.START],
-    'fail_alloc': 'red',
+    'fail_allocate': 'red',
     'fail_deploy': 'red',
     'fail_start': 'red',
 })
@@ -67,7 +68,10 @@ def display_data(instance):
     if not instance.data:
         return ''
     style = '<style>code,pre {font-size:1.13em;}</style><p></p>'
-    data = json.dumps(json.loads(instance.data), indent=4, ensure_ascii=False)
+    try:
+        data = json.dumps(json.loads(instance.data), indent=4, ensure_ascii=False)
+    except ValueError: # data is not a valid json string
+        data = instance.data
     data = break_lines(data)
     data = highlight(data, JsonLexer(), HtmlFormatter())
     return mark_safe(style + urlize(data))
@@ -76,14 +80,23 @@ display_data.short_description = 'data'
 
 def display_current(instance):
     try:
-        title = json.loads(instance.data).get('errors', '')
+        # Include error messages (if any) as tooltip
+        errors = json.loads(instance.data).get('errors', [])
     except ValueError:
         title = ''
     else:
-        title = str(title)[2:-2].replace("u'", "'")
+        title = '\n'.join([error.get('message', '') for error in errors])
+        title = escape(title).replace('\n', '&#10;')
     state = instance.current
     color = STATES_COLORS.get(state, "black")
-    state = filter(lambda s: s[0] == instance.current, State.STATES)[0][1]
+    try:
+        # check if the current state match with the defined ones
+        state = filter(lambda s: s[0] == instance.current, State.STATES)[0][1]
+    except IndexError:
+        # This situation can happen on State renames like on #385 and no data
+        # migration is applied to existing objects (we add a note but keep the
+        # app working because is not a big issue)
+        title = 'Invalid or legacy state'
     start = timezone.now()-datetime.timedelta(minutes=STATE_FLAPPING_MINUTES)
     changes = instance.history.filter(start__gt=start).count()
     if changes >= STATE_FLAPPING_CHANGES:
@@ -172,10 +185,10 @@ class StateHistoryAdmin(PermissionModelAdmin):
         return False
     
     def data_view(self, request, object_id):
-        history = get_object_or_404(State, pk=object_id)
+        history = get_object_or_404(StateHistory, pk=object_id)
         data = {
-            'metadata': display_metadata(history),
-            'data': display_data(history)
+            'metadata': display_metadata(history) or "(None)",
+            'data': display_data(history) or "(None)"
         }
         return HttpResponse(json.dumps(data), content_type="application/json")
     
