@@ -79,9 +79,6 @@ function print_install_requirements_help () {
 		    ${bold}-d, --development${normal}
 		        Installs minimal controller requirements using apt-get and pip
 		    
-		    ${bold}-l, --local${normal}
-		        Installs controller requirements for local deployments, i.e. VCT
-		    
 		    ${bold}-p, --production${normal}
 		        Installs all controller requirements using apt-get and pip (default)
 		    
@@ -93,18 +90,16 @@ function print_install_requirements_help () {
 
 
 function install_requirements () {
-    opts=$(getopt -o dlph -l development,local,production,help -- "$@") || exit 1
+    opts=$(getopt -o dph -l development,production,help -- "$@") || exit 1
     set -- $opts
     development=false
-    local=false
     production=true
     
     while [ $# -gt 0 ]; do
         case $1 in
             -d|--development) development=true; production=false; shift ;;
-            -l|--local) local=true; production=false; shift ;;
             -p|--production) production=true; shift ;;
-            -h|--help) print_deploy_help; exit 0 ;;
+            -h|--help) print_install_requirements_help; exit 0 ;;
             (--) shift; break;;
             (-*) echo "$0: Err. - unrecognized option $1" 1>&2; exit 1;;
             (*) break;;
@@ -123,36 +118,36 @@ function install_requirements () {
                      python-dateutil \
                      postgresql \
                      rabbitmq-server \
-                     python-dev gcc"
-    LOCAL_APT="fuseext2 file \
-               tinc \
-               libevent-dev"
+                     python-dev gcc \
+                     fuseext2 file \
+                     tinc \
+                     libevent-dev"
     
     PRODUCTION_APT="libjpeg8 libjpeg62-dev libfreetype6 libfreetype6-dev" # captcha
     
-    DEVELOPMENT_PIP="Django==1.6.1 \
-                     django-celery-email==1.0.3 \
-                     django-fluent-dashboard==0.3.5 \
+    DEVELOPMENT_PIP="Django==1.6.5 \
+                     django-celery-email==1.0.4 \
+                     django-fluent-dashboard==0.3.6 \
                      South==0.8.4 \
                      IPy==0.81 \
-                     django-extensions==1.1.1 \
+                     django-extensions==1.3.3 \
                      django-transaction-signals==1.0.0 \
                      django-celery==3.0.23 \
                      celery==3.0.24 \
                      kombu==2.5.14 \
-                     jsonfield==0.9.19 \
-                     Markdown==2.3.1 \
-                     django-filter==0.6 \
+                     jsonfield==0.9.20 \
+                     Markdown==2.4 \
+                     django-filter==0.7 \
                      django-admin-tools==0.5.1 \
-                     djangorestframework==2.3.9"
-    LOCAL_PIP="paramiko==1.11.0 \
-               Pygments==1.6 \
-               requests==1.2.0 \
-               gevent==0.13.8 \
-               simplejson" # TODO remove
-    PRODUCTION_PIP="django-simple-captcha==0.4.0 \
+                     djangorestframework==2.3.13 \
+                     paramiko==1.13.0 \
+                     Pygments==1.6 \
+                     requests==2.2.1 \
+                     greenlet==0.4.2 \
+                     gevent==1.0"
+    PRODUCTION_PIP="django-simple-captcha==0.4.2 \
                     django-registration==1.0 \
-                    django-google-maps==0.2.2"
+                    django-google-maps==0.2.3"
     
     # Make sure locales are in place before installing postgres
     if [[ $({ perl --help > /dev/null; } 2>&1|grep 'locale failed') ]]; then
@@ -170,10 +165,6 @@ function install_requirements () {
     sed -i "s/# Default-Stop:.*/# Default-Stop:      0 1 6/" /etc/init.d/rabbitmq-server
     run update-rc.d rabbitmq-server defaults
     
-    if ! $development; then
-        run apt-get install -y $LOCAL_APT
-        run pip install $LOCAL_PIP
-    fi
     if $production; then
         run apt-get install -y $PRODUCTION_APT
         # PIL has some mental problems with library paths
@@ -222,13 +213,13 @@ print_clone_help () {
 
 
 function clone () {
+    [ "$#" -lt 2 ] && echo "Err. - project name not provided." && exit 1
     local SKELETONE=false
-    local PROJECT_NAME="$2"; shift
+    local PROJECT_NAME="${2}"; shift
     
     opts=$(getopt -o s:h -l skeletone:,help -- "$@") || exit 1
     set -- $opts
     
-    set -- $opts
     while [ $# -gt 0 ]; do
         case $1 in
             -s|--skeletone) local SKELETONE="${2:1:${#2}-2}"; shift ;;
@@ -266,5 +257,12 @@ function clone () {
 export -f clone
 
 
-[ $# -lt 1 ] && print_help
-$1 "${@}"
+# check provided parameters
+if [ $# -lt 1 ]; then
+    print_help
+else
+    case $1 in
+        clone|install_requirements) $1 "${@}";;
+        *) print_help;;
+    esac
+fi
